# CTADIRAC project
* CTADIRAC is a customized version of the DIRAC interware. As of today, it allows an easy and optimized access to Grid resources (mainly EGI) available to the CTA Virtual Organization (vo.cta.in2p3.fr). When CTAO DPPS will be setup, CTADIRAC will serve as the Computing Ressource and Worflow Management System.
* CTADIRAC specific documentation can be found at:
  https://forge.in2p3.fr/projects/cta_dirac/wiki.
  

# Contribute to CTADIRAC:
* To contribute to CTADIRAC, please check out the full DIRAC developers guide at:
  http://dirac.readthedocs.io/en/integration/DeveloperGuide/index.html


# Release informations:
* Get CTADIRAC on pypi
  https://gitlab.cta-observatory.org/cta-computing/dpps/CTADIRAC/-/packages

# Contact Information
* Luisa Arrabito <arrabito@in2p3.fr>
